@@ -929,14 +929,16 @@ static Contact* parse_contact_info_by_no_response(const char* sipmsg)
 		int n;
 		res = xmlGetProp(node , BAD_CAST "carrier-region");
 		pos = (char*)res;
-		n = strlen(pos) - strlen(strstr(pos , "."));
-		strncpy(contact->country , pos , n);
-		pos = strstr(pos , ".") + 1;
-		n = strlen(pos) - strlen(strstr(pos , "."));
-		strncpy(contact->province , pos , n);
-		pos = strstr(pos , ".") + 1;
-		n = strlen(pos) - strlen(strstr(pos , "."));
-		strncpy(contact->city , pos , n);
+                if (!(pos == NULL || strcmp(pos, "") == 0)) {
+                    n = strlen(pos) - strlen(strstr(pos , "."));
+                    strncpy(contact->country , pos , n);
+                    pos = strstr(pos , ".") + 1;
+                    n = strlen(pos) - strlen(strstr(pos , "."));
+                    strncpy(contact->province , pos , n);
+                    pos = strstr(pos , ".") + 1;
+                    n = strlen(pos) - strlen(strstr(pos , "."));
+                    strncpy(contact->city , pos , n);
+                }
 		xmlFree(res);
 	}
 	if(xmlHasProp(node , BAD_CAST "portrait-crc"))
