@@ -15,8 +15,20 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.            *
+ *                                                                         *
+ *   OpenSSL linking exception                                             *
+ *   --------------------------                                            *
+ *   If you modify this Program, or any covered work, by linking or        *
+ *   combining it with the OpenSSL project's "OpenSSL" library (or a       *
+ *   modified version of that library), containing parts covered by        *
+ *   the terms of OpenSSL/SSLeay license, the licensors of this            *
+ *   Program grant you additional permission to convey the resulting       *
+ *   work. Corresponding Source for a non-source form of such a            *
+ *   combination shall include the source code for the parts of the        *
+ *   OpenSSL library used as well as that of the covered work.             *
  ***************************************************************************/
+
 #define _XOPEN_SOURCE
 #include <openfetion.h>
 
@@ -32,6 +44,7 @@ FetionSip* fetion_sip_new(FetionConnection* tcp , const char* sid)
 	sip->header = NULL;
 	return sip;
 }
+
 FetionSip* fetion_sip_clone(FetionSip* sip)
 {
 	FetionSip* res = (FetionSip*)malloc(sizeof(FetionSip));
@@ -40,6 +53,7 @@ FetionSip* fetion_sip_clone(FetionSip* sip)
 	sip->header = NULL;
 	return res;
 }
+
 SipHeader* fetion_sip_header_new(const char* name , const char* value)
 {
 	SipHeader* header = (SipHeader*)malloc(sizeof(SipHeader));
@@ -52,8 +66,9 @@ SipHeader* fetion_sip_header_new(const char* name , const char* value)
 	return header;
 }
 
-void fetion_sip_set_type(FetionSip* sip , SipType type)
+void fetion_sip_set_type(FetionSip *sip, SipType type)
 {
+	if(!sip) return;
 	sip->type = type;
 	sip->callid = callid;
 }
@@ -71,16 +86,17 @@ SipHeader* fetion_sip_authentication_header_new(const char* response)
 	char end[]   = "\",algorithm=\"SHA1-sess-v4\"";
 	SipHeader* header;
 	
-	len = strlen(start) + strlen(end) + strlen(response) + 1;
+	len = strlen(start) + strlen(end) + strlen(response) + 10;
 	res = (char*)malloc(len);
-	memset(res , 0 , len);
-	sprintf(res , "%s%s%s" , start , response , end);
+	memset(res, 0 , len);
+	sprintf(res, "%s%s%s" , start , response , end);
 	header = (SipHeader*)malloc(sizeof(SipHeader));
 	memset(header , 0 , sizeof(SipHeader));
 	strcpy(header->name , "A");
 	header->value = res;
 	return header;
 }
+
 SipHeader* fetion_sip_ack_header_new(const char* code , const char* algorithm , const char* type , const char* guid)
 {
 	char ack[512];
@@ -88,6 +104,7 @@ SipHeader* fetion_sip_ack_header_new(const char* code , const char* algorithm ,
 			 	, code , algorithm , type , guid);
 	return fetion_sip_header_new("A" , ack);
 }
+
 SipHeader* fetion_sip_event_header_new(int eventType)
 {
 	char event[48];
@@ -171,6 +188,7 @@ SipHeader* fetion_sip_event_header_new(int eventType)
 	}
 	return fetion_sip_header_new("N" , event);
 }
+
 SipHeader* fetion_sip_credential_header_new(const char* credential)
 {
 	char value[64];
@@ -178,6 +196,7 @@ SipHeader* fetion_sip_credential_header_new(const char* credential)
 	sprintf(value , "TICKS auth=\"%s\"" , credential);
 	return fetion_sip_header_new("A" , value);
 }
+
 void fetion_sip_add_header(FetionSip* sip , SipHeader* header)
 {
 	SipHeader* pos = sip->header;
@@ -378,44 +397,38 @@ int fetion_sip_get_type(const char* sip)
 char* fetion_sip_get_response(FetionSip* sip)
 {
 	char *res;
-	unsigned int len , n , c;
+	int len , n;
+   	int c, c1;
 	char buf[1024 * 20];
 
-	memset(buf , 0 , sizeof(buf));
+	memset(buf, 0, sizeof(buf));
 
-	c = tcp_connection_recv(sip->tcp , buf , sizeof(buf) - 2);
-
-	if(c == -1)
-		return NULL;
+	if((c = tcp_connection_recv(sip->tcp , buf , sizeof(buf) - 2)) == -1) return (char*)0;
 
 	len = fetion_sip_get_length(buf);
 
-	while(strstr(buf , "\r\n\r\n") == NULL && c < sizeof(buf))
+	while(strstr(buf , "\r\n\r\n") == NULL && c < (int)sizeof(buf))
 		c += tcp_connection_recv(sip->tcp, buf + c, sizeof(buf) - c - 1);
 	
 
 	n = strlen(buf) - strlen(strstr(buf , "\r\n\r\n") + 4);
 	len += n;
-	res = (char*)malloc(len + 1);
-	if(res == NULL)
-		return NULL;
-	memset(res , 0 , len + 1);
-	strcpy(res , buf);
-	if(c < len){
-		unsigned int c1;
-	   	for(;;){
-			memset(buf , 0 , sizeof(buf));
-			c1 = tcp_connection_recv(sip->tcp , buf
-					, len -c < (sizeof(buf) - 1) ? len -c : (sizeof(buf) - 1) );
-			if(c1 == -1){
-				free(res);
-				return NULL;
-			}
+	if(!(res = (char*)malloc(len + 10))) return (char*)0; 
+
+	memset(res, 0, len + 10);
+	strcpy(res, buf);
+	if(c < len) {
+	   	for(;;) {
+			memset(buf, 0, sizeof(buf));
+			if((c1 = tcp_connection_recv(sip->tcp , buf
+					, len -c < (int)(sizeof(buf) - 1) ? len -c : (int)(sizeof(buf) - 1) ))
+				== -1) {free(res); return (char*)0; }
 
 			strncpy(res + c, buf, c1);
 			c += c1;
-			if(c >= len)
+			if(c >= len) {
 				break;
+			}
 		}
 	}
 	return res;
@@ -509,7 +522,7 @@ SipMsg *fetion_sip_listen(FetionSip *sip, int *error)
 			/* now body_len != 0 */
 			pos += 4;
 			memset(holder, 0 , sizeof(holder));
-			if(strlen(pos) < body_len){
+			if((int)strlen(pos) < body_len){
 				strcpy(holder, cur);
 				tcp_connection_recv(sip->tcp,
 					holder + strlen(cur),
@@ -518,7 +531,7 @@ SipMsg *fetion_sip_listen(FetionSip *sip, int *error)
 				strcpy(buffer, holder);
 				cur = buffer;
 				continue;
-			}else if(strlen(pos) == body_len){
+			}else if((int)strlen(pos) == body_len){
 				msg = sipmsg_new();
 				sipmsg_set_msg(msg, cur, strlen(cur));
 				if(list)
@@ -722,8 +735,15 @@ void fetion_sip_parse_invitation(FetionSip* sip , Proxy *proxy , const char* sip
 
 	if(proxy != NULL && proxy->proxyEnabled)
 		tcp_connection_connect_with_proxy(conn , ipaddress , port , proxy);
-	else
-		tcp_connection_connect(conn , ipaddress , port);
+	else {
+		int ret = tcp_connection_connect(conn , ipaddress , port);
+		if(ret == -1)
+			ret = tcp_connection_connect(conn , ipaddress , 443);
+		if(ret == -1) {
+			debug_error("Connect to server failed: %s:%d/%s:%d", ipaddress, port, ipaddress, 443);
+			return;
+		}
+	}
 
 	*conversionSip = fetion_sip_clone(sip);
 	fetion_sip_set_connection(*conversionSip , conn);
@@ -840,8 +860,8 @@ void fetion_sip_parse_incoming(FetionSip* sip
 	}
 	node = node->xmlChildrenNode;
 	res = xmlNodeGetContent(node);
-	if(xmlStrcmp(res , BAD_CAST "nudge") == 0)
-	{
+	if(xmlStrcmp(res, BAD_CAST "nudge") == 0 ||
+		xmlStrcmp(res, BAD_CAST "input") == 0) {
 		*type = INCOMING_UNKNOWN;
 		*sipuri = (char*)malloc(50);
 		memset(replyMsg, 0, sizeof(replyMsg));
@@ -858,8 +878,10 @@ void fetion_sip_parse_incoming(FetionSip* sip
 						   "Q: %s\r\n\r\n"
 						 , *sipuri , callid , seq);
 		tcp_connection_send(sip->tcp , replyMsg , strlen(replyMsg));
-		
-		*type = INCOMING_NUDGE;
+		if(xmlStrcmp(res, BAD_CAST "nudge") == 0)
+			*type = INCOMING_NUDGE;
+		else
+			*type = INCOMING_INPUT;
 	}
 	xmlFree(res);
 	xmlFreeDoc(doc);
