@@ -15,7 +15,18 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.            *
+ *                                                                         *
+ *   OpenSSL linking exception                                             *
+ *   --------------------------                                            *
+ *   If you modify this Program, or any covered work, by linking or        *
+ *   combining it with the OpenSSL project's "OpenSSL" library (or a       *
+ *   modified version of that library), containing parts covered by        *
+ *   the terms of OpenSSL/SSLeay license, the licensors of this            *
+ *   Program grant you additional permission to convey the resulting       *
+ *   work. Corresponding Source for a non-source form of such a            *
+ *   combination shall include the source code for the parts of the        *
+ *   OpenSSL library used as well as that of the covered work.             *
  ***************************************************************************/
 
 #include <openfetion.h>
@@ -64,30 +75,39 @@ User* fetion_user_new(const char* no , const char* password)
 	return user;
 }
 
-void fetion_user_set_userid(User* user , const char* userid1)
+void fetion_user_set_userid(User* user, const char* userid1)
 {
-	strcpy(user->userId , userid1);
+	strcpy(user->userId, userid1);
 }
 
-void fetion_user_set_sid(User* user , const char* sId1)
+void fetion_user_set_sid(User* user, const char* sId1)
 {
-	strcpy(user->sId , sId1);
+	strcpy(user->sId, sId1);
 }
 
 void fetion_user_set_mobileno(User* user , const char* mobileno1)
 {
 	strcpy(user->mobileno , mobileno1);
 }
+
+void fetion_user_set_password(User *user, const char *password)
+{
+	strcpy(user->password, password);
+	user->password[strlen(password)] = '\0';
+}
+
 void fetion_user_set_sip(User* user , FetionSip* sip1)
 {
 	debug_info("Set a initialized Sip Struct to User");
 	user->sip = sip1;
 }
+
 void fetion_user_set_config(User* user , Config* config1)
 {
 	debug_info("Set a initialized Config Struct to User");
 	user->config = config1;
 }
+
 void fetion_user_set_verification_code(User* user , const char* code)
 {
 	user->verification->code = (char*)malloc(strlen(code) + 1);
@@ -445,7 +465,7 @@ int fetion_user_download_portrait_with_uri(User *user , const char *sipuri
 	if(config->proxy != NULL && config->proxy->proxyEnabled)
 		ret = tcp_connection_connect_with_proxy(tcp , ip , 80 , config->proxy);
 	else
-		ret = tcp_connection_connect(tcp , ip , 80);
+		ret = tcp_connection_connect(tcp, ip, 80);
 	if(ret < 0){
 		debug_error("connect to portrait server:%s",
 				strerror(errno));
